'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.immutableAsyncReducers = undefined;

var _immutable = require('immutable');

var _constant = require('./constant');

var initialState = (0, _immutable.Map)({
  status: _constant.ASYNC.IDLE,
  isFetching: false,
  isError: false,
  data: {},
  error: {}
});

var immutableAsyncReducers = exports.immutableAsyncReducers = function immutableAsyncReducers(ASYNC_ACTION_NAMES) {
  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
    var action = arguments[1];

    switch (action.type) {
      case ASYNC_ACTION_NAMES.GET:
      case ASYNC_ACTION_NAMES.POST:
        return state.merge({
          status: _constant.ASYNC.PROCESS,
          isFetching: true,
          isError: false
        });
      case ASYNC_ACTION_NAMES.RECEIVE:
        return state.merge({
          status: _constant.ASYNC.SUCCESS,
          isFetching: false,
          isError: false,
          data: action.payload
        });
      case ASYNC_ACTION_NAMES.ERROR:
        return state.merge({
          status: _constant.ASYNC.ERROR,
          isFetching: false,
          isError: true,
          error: action.payload
        });
      case ASYNC_ACTION_NAMES.RESET:
        return state.merge(initialState);
      default:
        return state;
    }
  };
};

// *TODO: adding normal javascript state store support

exports.default = immutableAsyncReducers;